==> manage-1.1.32-2.jar: management/sqls/营收/报表管理/收费类/操作日结账报表/gaspropet.sql <==


select 
        f_gasproperties_type,f_gasproperties,SUM(c) c,
        SUM(f_collection) f_collection,SUM(f_delaypay) f_delaypay,
        (SUM(f_collection)+SUM(f_delaypay)) xiaoji,
        sum(ycgas) ycgas,SUM(ycmoney) ycmoney,
        SUM(zhinum) zhinum,SUM(xiannum) xiannum,SUM(zhimoney) zhimoney,SUM(xianmoney) xianmoney,
        SUM(collect)  collect,SUM(zhigas) zhigas,SUM(xiangas) xiangas,0 anfee,0 zanfee,0 qifee

  from(
        select 
               c.f_gasproperties_type,s.f_gasproperties,
               count(distinct s.f_userinfo_id) c,SUM(f_collection)-SUM(f_delaypay) f_collection,
               SUM(f_delaypay) f_delaypay,0 ycgas,0 ycmoney,0 zhinum,0 xiannum,0 zhimoney,0 xianmoney,0 collect,0 zhigas,0 xiangas
          from
               (
                 select 
                       f_price_id,f_preamount,id,f_gasproperties,f_userinfo_id,
                       isnull(f_collection,0) f_collection,isnull(f_delaypay,0) f_delaypay
                   from 
                       t_sellinggas
                   where f_charge_state!='无效'  and f_delivery_date>='{startDate}' 
                         and f_delivery_date<='{endDate}' and  
		                 {operator != $$ && outlets != $$:
       					 $
        				 f_operator='{operator}' and f_outlets='{outlets}'
        			     $,
        				 outlets != $$:
        				 $
        				 f_outlets='{outlets}'
        				 $,
        				 operator != $$:
        				 $
        				 f_operator='{operator}'
        				 $,
        				 operator == $$ && outlets == $$:
         				 $
        				 1=1
				        $,
				        $$
						} and 
						{filiale != $$:
				        $
				        	f_filiale='{filiale}'
				        $,
				        filiale == $$:
				        $
				        	1=1
				        $,
				        $$
						}
	                  and id not in 
	                  (
					     select f_correct_id 
					     from t_correctrecord
					     where f_correct_type='收费冲正' and 
						       f_correct_date>='{startDate}' and f_correct_date<='{endDate}'
						       and f_correct_id is not null
					 )
                ) s
                left join
                        (
					    select f_price_id, f_gasproperties_type
					    from t_stairprice
      			) c  on c.f_price_id =s.f_price_id
          group by s.f_gasproperties,c.f_gasproperties_type
  union all 
  select   
         p.f_gasproperties_type,s.f_gasproperties,0 c,0 f_collection,0 f_delaypay,0 ycgas,0 ycmoney,
         SUM(isnull(weinum,0))+SUM(isnull(zhinum,0)) zhinum,
         SUM(isnull(xiannum,0)) xiannum,
         SUM(isnull(weimoney,0))+SUM(isnull(zhimoney,0)) zhimoney,
         SUM(isnull(xianmoney,0)) xianmoney,0  collect, SUM(isnull(weigas,0))+SUM(isnull(zhigas,0))  zhigas,
         SUM(isnull(xiangas,0)) xiangas
    from 
        (
         select  
               s.f_gasproperties,s.f_price_id,
		       case when s.f_payment='微信缴费'  then COUNT(s.f_price_id) end weinum,
		       case when s.f_payment='支付宝缴费'  then COUNT(s.f_price_id) end zhinum,
		       case when s.f_payment='现金缴费'  then COUNT(s.f_price_id) end xiannum,
		       case when s.f_payment='微信缴费'  then sum(b.f_paid_money) end weimoney,
		       case when s.f_payment='支付宝缴费'  then sum(b.f_paid_money) end zhimoney,
		       case when s.f_payment='现金缴费'  then sum(b.f_paid_money) end xianmoney,0  f_collection,
		       case when s.f_payment='微信缴费'  then sum(s.f_pregas) end weigas,
		       case when s.f_payment='支付宝缴费'  then sum(s.f_pregas) end zhigas,
		       case when s.f_payment='现金缴费'  then sum(s.f_pregas) end xiangas
        from (
               select 
                     isnull(f_paid_money ,0) f_paid_money,f_billdetail_id,f_bill_type 
                from t_billdetail
                where f_bill_type like '%补打%'
                      and f_operate_date>='{startDate}' and f_operate_date<='{endDate}'
                      and f_billdetail_id is not null and f_bill_state='已用' and 
			        {operator != $$ && outlets != $$:
			        $
			        	f_operator='{operator}' and f_outlets='{outlets}'
			        $,
			        outlets != $$:
			        $
			        	f_outlets='{outlets}'
			        $,
			        operator != $$:
			        $
			        	f_operator='{operator}'
			        $,
			        operator == $$ && outlets == $$:
			        $
			        	1=1
			        $,
			        $$
					} and 
					{filiale != $$:
			        $
			        	f_filiale='{filiale}'
			        $,
			        filiale == $$:
			        $
			        	1=1
			        $,
			        $$
					}
            ) b
      left join
           (
            select id,f_price_id,f_gasproperties,f_payment,f_pregas 
            from t_sellinggas
        ) s on s.id=b.f_billdetail_id
      group by s.f_gasproperties,s.f_price_id,s.f_payment
    ) s
   left join
        (
           select f_price_id, f_gasproperties_type
          from t_stairprice
        ) p on s.f_price_id=p.f_price_id 
 group by p.f_gasproperties_type,s.f_gasproperties   
union all
  select 
       s.f_gasproperties_type,u.f_gasproperties, 
       0 c,0 f_collection,0 f_delaypay,0 ycgas,0 ycmoney,0 zhinum,0 xiannum,0 zhimoney,0 xianmoney,
       SUM(isnull(u.f_collection,0)) collect,0 zhigas,0 xiangas 
  from(
       select h.*,u.f_price_id 
       from
       (
         select u.f_gasproperties,f_collection,u.f_userinfo_id
         from t_othercharge o                 
         left join 
             t_userinfo u  on o.f_userinfo_id = u.f_userinfo_id 
         where  f_charge_state='有效' and f_operate_date>='{startDate}' and f_operate_date<='{endDate}' 
         and   
        {operator != $$ && outlets != $$:
        $
        	o.f_operator='{operator}' and o.f_outlets='{outlets}'
        $,
        outlets != $$:
        $
        	o.f_outlets='{outlets}'
        $,
        operator != $$:
        $
        	o.f_operator='{operator}'
        $,
        operator == $$ && outlets == $$:
        $
        	1=1
        $,
        $$
		} and 
		{filiale != $$:
        $
        	o.f_filiale='{filiale}'
        $,
        filiale == $$:
        $
        	1=1
        $,
        $$
		}
        ) h
        left join
        (
         select f_price_id,f_userinfo_id 
         from t_userfiles 
        ) u on u.f_userinfo_id=h.f_userinfo_id
    ) u 
    left join
    t_stairprice s on u.f_price_id=s.f_price_id
    group by s.f_gasproperties_type,u.f_gasproperties
) s
where s.f_gasproperties_type is not null
group by f_gasproperties_type,f_gasproperties

==> manage-3.1.0-40.jar: management/sqls/营收/报表管理/收费类/操作日结账报表/gaspropet.sql <==


select 
        f_gasproperties_type,f_gasproperties,SUM(c) c,
        SUM(f_collection) f_collection,SUM(f_delaypay) f_delaypay,
        (SUM(f_collection)+SUM(f_delaypay)) xiaoji,
        sum(ycgas) ycgas,SUM(ycmoney) ycmoney,
        SUM(zhinum) zhinum,SUM(xiannum) xiannum,SUM(zhimoney) zhimoney,SUM(xianmoney) xianmoney,
        SUM(collect)  collect,SUM(zhigas) zhigas,SUM(xiangas) xiangas,0 anfee,0 zanfee,0 qifee

  from(
        select 
               c.f_gasproperties_type,s.f_gasproperties,
               count(distinct s.f_userinfo_id) c,SUM(f_collection)-SUM(f_delaypay) f_collection,
               SUM(f_delaypay) f_delaypay,0 ycgas,0 ycmoney,0 zhinum,0 xiannum,0 zhimoney,0 xianmoney,0 collect,0 zhigas,0 xiangas
          from
               (
                 select 
                       f_price_id,f_preamount,id,f_gasproperties,f_userinfo_id,
                       isnull(f_collection,0) f_collection,isnull(f_delaypay,0) f_delaypay
                   from 
                       t_sellinggas
                   where f_state!='无效'  and f_operate_date>='{startDate}'
                         and f_operate_date<='{endDate}' and
		                 {operator != $$ && outlets != $$:
       					 $
        				 f_operator='{operator}' and f_outlets='{outlets}'
        			     $,
        				 outlets != $$:
        				 $
        				 f_outlets='{outlets}'
        				 $,
        				 operator != $$:
        				 $
        				 f_operator='{operator}'
        				 $,
        				 operator == $$ && outlets == $$:
         				 $
        				 1=1
				        $,
				        $$
						} and 
						{filiale != $$:
				        $
				        	f_filiale='{filiale}'
				        $,
				        filiale == $$:
				        $
				        	1=1
				        $,
				        $$
						}
	                  and id not in 
	                  (
					     select f_correct_id 
					     from t_correctrecord
					     where f_correct_type='收费冲正' and 
						       f_correct_date>='{startDate}' and f_correct_date<='{endDate}'
						       and f_correct_id is not null
					 )
                ) s
                left join
                        (
					    select f_price_id, f_gasproperties_type
					    from t_stairprice
      			) c  on c.f_price_id =s.f_price_id
          group by s.f_gasproperties,c.f_gasproperties_type
  union all 
  select   
         p.f_gasproperties_type,s.f_gasproperties,0 c,0 f_collection,0 f_delaypay,0 ycgas,0 ycmoney,
         SUM(isnull(weinum,0))+SUM(isnull(zhinum,0)) zhinum,
         SUM(isnull(xiannum,0)) xiannum,
         SUM(isnull(weimoney,0))+SUM(isnull(zhimoney,0)) zhimoney,
         SUM(isnull(xianmoney,0)) xianmoney,0  collect, SUM(isnull(weigas,0))+SUM(isnull(zhigas,0))  zhigas,
         SUM(isnull(xiangas,0)) xiangas
    from 
        (
         select  
               s.f_gasproperties,s.f_price_id,
		       case when s.f_payment='微信缴费'  then COUNT(s.f_price_id) end weinum,
		       case when s.f_payment='支付宝缴费'  then COUNT(s.f_price_id) end zhinum,
		       case when s.f_payment='现金缴费'  then COUNT(s.f_price_id) end xiannum,
		       case when s.f_payment='微信缴费'  then sum(b.f_paid_money) end weimoney,
		       case when s.f_payment='支付宝缴费'  then sum(b.f_paid_money) end zhimoney,
		       case when s.f_payment='现金缴费'  then sum(b.f_paid_money) end xianmoney,0  f_collection,
		       case when s.f_payment='微信缴费'  then sum(s.f_pregas) end weigas,
		       case when s.f_payment='支付宝缴费'  then sum(s.f_pregas) end zhigas,
		       case when s.f_payment='现金缴费'  then sum(s.f_pregas) end xiangas
        from (
               select 
                     isnull(f_paid_money ,0) f_paid_money,f_billdetail_id,f_bill_type 
                from t_billdetail
                where f_bill_type like '%补打%'
                      and f_operate_date>='{startDate}' and f_operate_date<='{endDate}'
                      and f_billdetail_id is not null and f_bill_state='已用' and 
			        {operator != $$ && outlets != $$:
			        $
			        	f_operator='{operator}' and f_outlets='{outlets}'
			        $,
			        outlets != $$:
			        $
			        	f_outlets='{outlets}'
			        $,
			        operator != $$:
			        $
			        	f_operator='{operator}'
			        $,
			        operator == $$ && outlets == $$:
			        $
			        	1=1
			        $,
			        $$
					} and 
					{filiale != $$:
			        $
			        	f_filiale='{filiale}'
			        $,
			        filiale == $$:
			        $
			        	1=1
			        $,
			        $$
					}
            ) b
      left join
           (
            select id,f_price_id,f_gasproperties,f_payment,f_pregas 
            from t_sellinggas
        ) s on s.id=b.f_billdetail_id
      group by s.f_gasproperties,s.f_price_id,s.f_payment
    ) s
   left join
        (
           select f_price_id, f_gasproperties_type
          from t_stairprice
        ) p on s.f_price_id=p.f_price_id 
 group by p.f_gasproperties_type,s.f_gasproperties   
union all
  select 
       s.f_gasproperties_type,u.f_gasproperties, 
       0 c,0 f_collection,0 f_delaypay,0 ycgas,0 ycmoney,0 zhinum,0 xiannum,0 zhimoney,0 xianmoney,
       SUM(isnull(u.f_collection,0)) collect,0 zhigas,0 xiangas 
  from(
       select h.*,u.f_price_id 
       from
       (
         select u.f_gasproperties,f_collection,u.f_userinfo_id
         from t_othercharge o                 
         left join 
             t_userinfo u  on o.f_userinfo_id = u.f_userinfo_id 
         where  f_state='有效' and f_operate_date>='{startDate}' and f_operate_date<='{endDate}'
         and   
        {operator != $$ && outlets != $$:
        $
        	o.f_operator='{operator}' and o.f_outlets='{outlets}'
        $,
        outlets != $$:
        $
        	o.f_outlets='{outlets}'
        $,
        operator != $$:
        $
        	o.f_operator='{operator}'
        $,
        operator == $$ && outlets == $$:
        $
        	1=1
        $,
        $$
		} and 
		{filiale != $$:
        $
        	o.f_filiale='{filiale}'
        $,
        filiale == $$:
        $
        	1=1
        $,
        $$
		}
        ) h
        left join
        (
         select f_price_id,f_userinfo_id 
         from t_userfiles 
        ) u on u.f_userinfo_id=h.f_userinfo_id
    ) u 
    left join
    t_stairprice s on u.f_price_id=s.f_price_id
    group by s.f_gasproperties_type,u.f_gasproperties
) s
where s.f_gasproperties_type is not null
group by f_gasproperties_type,f_gasproperties
